@@ -11,5 +11,5 @@ BSDSRCDIR="${bsd-srcdir}"
 TARGET="${target}"
 EOF
 
-cd "$BSDSRCDIR"
+cd "${BSDSRCDIR}"
 make -f Makefile.cross "TARGET=${TARGET}" "CROSSDIR=${CROSSDIR}" cross-dirs
