@@ -4,11 +4,10 @@
 
 config_load <<-'EOF'
 BUILDDIR="${builddir}"
+TMPDIR="${tmp-dir}"
 EOF
 
-_tmpdir="${BUILDDIR}/tmp"
-
-case "$_MODE" in
+case "${_MODE}" in
 robsd)
 	config_load <<-'EOF'
 	BSDSRCDIR="${bsd-srcdir}"
@@ -16,13 +15,13 @@ robsd)
 	XSRCDIR="${x11-srcdir}"
 	EOF
 
-	diff_list "$BUILDDIR" "src.diff" |
+	diff_list "${BUILDDIR}" "src.diff" |
 	while read -r _diff; do
-		diff_apply -d "$BSDSRCDIR" -t "$_tmpdir" -u "$CVSUSER" "$_diff"
+		diff_apply -d "${BSDSRCDIR}" -t "${TMPDIR}" -u "${CVSUSER}" "${_diff}"
 	done
-	diff_list "$BUILDDIR" "xenocara.diff" |
+	diff_list "${BUILDDIR}" "xenocara.diff" |
 	while read -r _diff; do
-		diff_apply -d "$XSRCDIR" -t "$_tmpdir" -u "$CVSUSER" "$_diff"
+		diff_apply -d "${XSRCDIR}" -t "${TMPDIR}" -u "${CVSUSER}" "${_diff}"
 	done
 	;;
 robsd-ports)
@@ -32,10 +31,10 @@ robsd-ports)
 	PORTSDIR="${ports-dir}"
 	EOF
 
-	diff_list "$BUILDDIR" "ports.diff" |
+	diff_list "${BUILDDIR}" "ports.diff" |
 	while read -r _diff; do
-		diff_apply -d "${CHROOT}${PORTSDIR}" -t "$_tmpdir" \
-			-u "$CVSUSER" "$_diff"
+		diff_apply -d "${CHROOT}${PORTSDIR}" -t "${TMPDIR}" \
+			-u "${CVSUSER}" "${_diff}"
 	done
 	;;
 robsd-regress)
@@ -44,9 +43,9 @@ robsd-regress)
 	CVSUSER="${cvs-user}"
 	EOF
 
-	diff_list "$BUILDDIR" "src.diff" |
+	diff_list "${BUILDDIR}" "src.diff" |
 	while read -r _diff; do
-		diff_apply -d "$BSDSRCDIR" -t "$_tmpdir" -u "$CVSUSER" "$_diff"
+		diff_apply -d "${BSDSRCDIR}" -t "${TMPDIR}" -u "${CVSUSER}" "${_diff}"
 	done
 	;;
 *)
