@@ -5,11 +5,13 @@ XOBJDIR="${x11-objdir}"; export XOBJDIR
 XSRCDIR="${x11-srcdir}"; export XSRCDIR
 EOF
 
-cleandir "$XOBJDIR"
-chown build:wobj "$XOBJDIR"
-chmod 770 "$XOBJDIR"
+PATH="${PATH}:/usr/X11R6/bin"; export PATH
 
-cd "$XSRCDIR"
+cleandir "${XOBJDIR}"
+chown build:wobj "${XOBJDIR}"
+chmod 770 "${XOBJDIR}"
+
+cd "${XSRCDIR}"
 make bootstrap
 make obj
 make build
