@@ -7,17 +7,19 @@ RELEASEDIR="${x11-reldir}"; export RELEASEDIR
 XSRCDIR="${x11-srcdir}"
 EOF
 
-DESTDIR="${DESTDIR}/xenocara"; export DESTDIR
-mkdir -p "$DESTDIR"
-cleandir "$DESTDIR"
+PATH="${PATH}:/usr/X11R6/bin"; export PATH
 
-mkdir -p "$RELEASEDIR"
-cleandir "$RELEASEDIR"
-chown build "$RELEASEDIR"
-chmod 755 "$RELEASEDIR"
+DESTDIR="${DESTDIR}/xenocara"; export DESTDIR
+mkdir -p "${DESTDIR}"
+cleandir "${DESTDIR}"
+
+mkdir -p "${RELEASEDIR}"
+cleandir "${RELEASEDIR}"
+chown build "${RELEASEDIR}"
+chmod 755 "${RELEASEDIR}"
 
 # Not suitable for parallelism.
 unset MAKEFLAGS
-cd "$XSRCDIR"
+cd "${XSRCDIR}"
 make release
 make checkdist
