@@ -40,9 +40,13 @@ build_date() {
 build_id() {
 	local _c
 	local _d
+	local _robsddir
+
+	_robsddir="$1"; : "${_robsddir:?}"
 
 	_d="$(date '+%Y-%m-%d')"
-	_c="$(find "$1" -type d -name "${_d}*" | wc -l)"
+	_c="$(cd "${_robsddir}" && find . -type d -name "${_d}*" |
+	      sort -nr | head -1 | cut -d '.' -f 3)"
 	printf '%s.%d\n' "${_d}" "$((_c + 1))"
 }
 
@@ -229,7 +233,7 @@ cvs_date() {
 	_log="${_builddir}/$(step_value log 2>/dev/null || :)"
 	_date="$(grep -m 1 '^Date:' "${_log}" | sed -e 's/^[^:]*: *//' || :)"
 	if [ -n "${_date}" ]; then
-		date -j -f '%Y/%m/%d %H:%M:%S' '+%s' "${_date}"
+		date -u -j -f '%Y/%m/%d %H:%M:%S' '+%s' "${_date}"
 	else
 		step_value time
 	fi
@@ -1123,12 +1127,10 @@ step_eval() {
 #
 # Execute the given script and redirect any output to log.
 step_exec() (
-	local _err
-	local _fail
+	local _err=0
 	local _log
 	local _step
 	local _trace="yes"
-	local _tmpdir
 
 	while [ $# -gt 0 ]; do
 		case "$1" in
@@ -1142,24 +1144,25 @@ step_exec() (
 	: "${_log:?}"
 	: "${_step:?}"
 
-	_tmpdir="$(config_value tmp-dir)"
-	_fail="$(mktemp -p "${_tmpdir}" step-exec.XXXXXX)"
-	echo 0 >"${_fail}"
+	set -o pipefail
 
 	[ "${DETACH}" -eq 0 ] || exec >/dev/null 2>&1
 
-	{
-		"${ROBSDEXEC}" -m "${_MODE}" ${ROBSDCONF:+"-C${ROBSDCONF}"} \
-			${_trace:+-x} "${_step}" || echo "$?" >"${_fail}"
+	# Caution, ROBSDEXEC is intentionally not quoted as some tests injects
+	# arguments.
+	${ROBSDEXEC} -m "${_MODE}" ${ROBSDCONF:+"-C${ROBSDCONF}"} \
+		${_trace:+-x} "${_step}" </dev/null 2>&1 |
+	tee "${_log}" || _err="$?"
+
+	# Regress tests can fail but still exit zero, check the log for
+	# failures. However, give timeouts higher precedence.
+	if [ "${_MODE}" = "robsd-regress" ] &&
+	   [ "${_err}" -ne 124 ] &&
+	   regress_failed "${_log}"
+	then
+		_err=1
+	fi
 
-		if [ "${_MODE}" = "robsd-regress" ]; then
-			# Regress tests can fail but still exit zero, check the
-			# log for failures.
-			regress_failed "${_log}" && echo 1 >"${_fail}"
-		fi
-	} </dev/null 2>&1 | tee "${_log}"
-	_err="$(<"${_fail}")"
-	rm -f "${_fail}"
 	return "${_err}"
 )
 
